| lmerUvcov-class | R Documentation |
A mixed-effects model fit by lmerUvcov.
This class extends class "merMod" class and includes one
additional slot, relfac, which is a list of (left) Cholesky
factors of the relationship matrices derived from
user provided variance covariance matrixes.
Objects are created by calls to the
lmerUvcov function.
Class "merMod", directly.
signature(object = "lmerUvcov"): incorporates
the user defined variance covariance matrix into the random effects as returned for the object
viewed as a "merMod" object.
lmerUvcov
showClass("lmerUvcov")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.